/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
.button {
  position: relative;
  display: inline-block;
  vertical-align: top;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -o-text-overflow: ellipsis;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
  text-decoration: none;
}
.button--quiet {
  background: transparent;
  border: 1px solid transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.button--disabled {
  opacity: 0.3;
  cursor: default;
  pointer-events: none;
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
.button,
.topcoat-button,
.topcoat-button--quiet,
.topcoat-button--large,
.topcoat-button--large--quiet,
.topcoat-button--cta,
.topcoat-button--large--cta {
  position: relative;
  display: inline-block;
  vertical-align: top;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -o-text-overflow: ellipsis;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
  text-decoration: none;
}
.button--quiet {
  background: transparent;
  border: 1px solid transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.button--disabled,
.topcoat-button:disabled,
.topcoat-button.is-disabled,
.topcoat-button--quiet:disabled,
.topcoat-button--quiet.is-disabled,
.topcoat-button--large:disabled,
.topcoat-button--large.is-disabled,
.topcoat-button--large--quiet:disabled,
.topcoat-button--large--quiet.is-disabled,
.topcoat-button--cta:disabled,
.topcoat-button--cta.is-disabled,
.topcoat-button--large-cta:disabled,
.topcoat-button--large--cta.is-disabled {
  opacity: 0.3;
  cursor: default;
  pointer-events: none;
}
/*
 Button
 ------

 :active - Active state

 .is-active - Simulates an active state on mobile devices

 :disabled - Disabled state

 .is-disabled - Simulates a disabled state on mobile devices

    <button class="topcoat-button">Button</button>
    <button class="topcoat-button is-active">Button</button>
    <button class="topcoat-button is-disabled">Button</button>
*/
.topcoat-button,
.topcoat-button--quiet,
.topcoat-button--large,
.topcoat-button--large--quiet,
.topcoat-button--cta,
.topcoat-button--large--cta {
  padding: 0 1.16rem;
  font-size: 12px;
  line-height: 2rem;
  letter-spacing: 1px;
  color: #c6c8c8;
  text-shadow: 0 -1px rgba(0,0,0,0.69);
  vertical-align: top;
  background-color: #595b5b;
  -webkit-box-shadow: inset 0 1px rgba(255,255,255,0.12);
  box-shadow: inset 0 1px rgba(255,255,255,0.12);
  border: 1px solid rgba(0,0,0,0.36);
  -webkit-border-radius: 3px;
  border-radius: 3px;
}
.topcoat-button:active,
.topcoat-button.is-active,
.topcoat-button--large:active,
.topcoat-button--large.is-active {
  background-color: #404141;
  -webkit-box-shadow: inset 0 1px rgba(0,0,0,0.18);
  box-shadow: inset 0 1px rgba(0,0,0,0.18);
}
/*
 Quiet Button
 ------------

 :active - Quiet button active state

 .is-active - Simulates active state for a quiet button on touch interfaces

 :disabled - Disabled state

 .is-disabled - Simulates disabled state

    <button class="topcoat-button--quiet">Button</button>
    <button class="topcoat-button--quiet is-active">Button</button>
    <button class="topcoat-button--quiet is-disabled">Button</button>
*/
.topcoat-button--quiet {
  background: transparent;
  border: 1px solid transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.topcoat-button--quiet:active,
.topcoat-button--quiet.is-active,
.topcoat-button--large--quiet:active,
.topcoat-button--large--quiet.is-active {
  color: #c6c8c8;
  text-shadow: 0 -1px rgba(0,0,0,0.69);
  background-color: #404141;
  border: 1px solid rgba(0,0,0,0.36);
  -webkit-box-shadow: inset 0 1px rgba(0,0,0,0.18);
  box-shadow: inset 0 1px rgba(0,0,0,0.18);
}
/*
 Large Button
 ------------

 :active - Active state

 .is-active - Simulates active state touch interfaces

 :disabled - Disabled state

 .is-disabled - Simulates disabled state

    <button class="topcoat-button--large" >Button</button>
    <button class="topcoat-button--large is-active" >Button</button>
    <button class="topcoat-button--large is-disabled" >Button</button>
*/
.topcoat-button--large,
.topcoat-button--large--quiet {
  font-size: 1.167rem;
  line-height: 2.6rem;
}
/*
 Large Quiet Button
 ------------------

 :active - Active state

 .is-pressed - Simulates active state on touch interfaces

 :disabled - Disabled state

 .is-disabled - Simulates disabled state


    <button class="topcoat-button--large--quiet" >Button</button>
    <button class="topcoat-button--large--quiet is-active" >Button</button>
    <button class="topcoat-button--large--quiet is-disabled" >Button</button>
*/
.topcoat-button--large--quiet {
  background: transparent;
  border: 1px solid transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}
/*
 Call To Action Button
 ---------------------

 :active - Active state

 .is-pressed - Simulates active state on touch interfaces

 :disabled - Disabled state

 .is-disabled - Simulates disabled state


    <button class="topcoat-button--cta" >Button</button>
    <button class="topcoat-button--cta is-active" >Button</button>
    <button class="topcoat-button--cta is-disabled" >Button</button>

*/
.topcoat-button--cta,
.topcoat-button--large--cta {
  border: 1px solid #143250;
  background-color: #288edf;
  -webkit-box-shadow: inset 0 1px rgba(255,255,255,0.36);
  box-shadow: inset 0 1px rgba(255,255,255,0.36);
  color: #fff;
  font-weight: 500;
  text-shadow: 0 -1px rgba(0,0,0,0.36);
}
.topcoat-button--cta:active,
.topcoat-button--cta.is-active,
.topcoat-button--large--cta:active,
.topcoat-button--large--cta.is-active {
  background-color: #1976c3;
  -webkit-box-shadow: inset 0 1px rgba(0,0,0,0.12);
  box-shadow: inset 0 1px rgba(0,0,0,0.12);
}
/*
 Large Call To Action Button
 ---------------------------

 :active - Active state

 .is-active - Simulates active state touch interfaces

 :disabled - Disabled state

 .is-disabled - Simulates disabled state

    <button class="topcoat-button--large--cta" >Button</button>
    <button class="topcoat-button--large--cta is-active" >Button</button>
    <button class="topcoat-button--large--cta is-disabled" >Button</button>
*/
.topcoat-button--large--cta {
  font-size: 1.167rem;
  line-height: 2.6rem;
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
input[type="checkbox"] {
  position: absolute;
  overflow: hidden;
  padding: 0;
  border: 0;
  opacity: 0.001;
  z-index: 1;
  vertical-align: top;
  outline: none;
}
.checkbox {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  position: relative;
  display: inline-block;
  vertical-align: top;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.checkbox__label {
  position: relative;
  display: inline-block;
  vertical-align: top;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.checkbox--disabled {
  opacity: 0.3;
  cursor: default;
  pointer-events: none;
}
.checkbox:before,
.checkbox:after {
  content: '';
  position: absolute;
}
.checkbox:before {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
input[type="checkbox"] {
  position: absolute;
  overflow: hidden;
  padding: 0;
  border: 0;
  opacity: 0.001;
  z-index: 1;
  vertical-align: top;
  outline: none;
}
.checkbox,
.topcoat-checkbox {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  position: relative;
  display: inline-block;
  vertical-align: top;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.checkbox__label,
.topcoat-checkbox__label {
  position: relative;
  display: inline-block;
  vertical-align: top;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.checkbox--disabled,
.topcoat-checkbox__label:disabled,
.topcoat-checkbox__label.is-disabled {
  opacity: 0.3;
  cursor: default;
  pointer-events: none;
}
.checkbox:before,
.checkbox:after,
.topcoat-checkbox:before,
.topcoat-checkbox:after {
  content: '';
  position: absolute;
}
.checkbox:before,
.topcoat-checkbox:before {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
}
/*
 Checkbox
 --------

 :focus - Focus state

 .is-focused - Simulates an focus state on mobile devices

 :disabled - Disabled state

 .is-disabled - Simulates a disabled state on mobile devices

     <label class="topcoat-checkbox__label">
         <input type="checkbox">
         <div class="topcoat-checkbox"></div>
         Default
     </label>

     <br>
     <br>

     <label class="topcoat-checkbox__label is-active">
         <input type="checkbox">
         <div class="topcoat-checkbox"></div>
         Active
     </label>

     <br>
     <br>

     <label class="topcoat-checkbox__label is-focused">
         <input type="checkbox">
         <div class="topcoat-checkbox"></div>
         Focused
     </label>

     <br>
     <br>

     <label class="topcoat-checkbox__label is-disabled">
         <input type="checkbox">
         <div class="topcoat-checkbox"></div>
         Disabled
     </label>
*/
.topcoat-checkbox {
  height: 1rem;
}
input[type="checkbox"] {
  height: 1rem;
  width: 1rem;
  margin-top: 0;
  margin-right: -1rem;
  margin-bottom: -1rem;
  margin-left: 0;
}
input[type="checkbox"]:checked + .topcoat-checkbox:after,
.topcoat-checkbox__label.is-active > .topcoat-checkbox:after {
  opacity: 1;
}
.topcoat-checkbox__label {
  line-height: 1rem;
}
.topcoat-checkbox:before {
  width: 1rem;
  height: 1rem;
  background: #595b5b;
  border: 1px solid rgba(0,0,0,0.36);
  -webkit-border-radius: 3px;
  border-radius: 3px;
  -webkit-box-shadow: inset 0 1px rgba(255,255,255,0.12);
  box-shadow: inset 0 1px rgba(255,255,255,0.12);
}
.topcoat-checkbox {
  width: 1rem;
  height: 1rem;
}
.topcoat-checkbox:after {
  top: 3px;
  opacity: 0;
  width: 11px;
  height: 4px;
  background: transparent;
  border: 7px solid #fff;
  border-width: 3px;
  border-top: none;
  border-right: none;
  -webkit-border-radius: 1px;
  border-radius: 1px;
  -webkit-transform: rotate(-50deg);
  -moz-transform: rotate(-50deg);
  -o-transform: rotate(-50deg);
  -ms-transform: rotate(-50deg);
  transform: rotate(-50deg);
}
input[type="checkbox"]:focus + .topcoat-checkbox:before,
.topcoat-checkbox__label.is-focused > .topcoat-checkbox:before {
  border: 1px solid #0940fd;
  -webkit-box-shadow: 0 0 0 2px #6fb5f1;
  box-shadow: 0 0 0 2px #6fb5f1;
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
.input {
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  vertical-align: top;
  outline: none;
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
.list-container {
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  overflow: auto;
  -webkit-overflow-scrolling: touch;
}
.list {
  padding: 0;
  margin: 0;
  list-style-type: none;
}
.list-item {
  margin: 0;
  padding: 0;
}


/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
/*
 List
 ------------

    <div class="topcoat-list__container">
      <h3 class="topcoat-list__header">Category</h3>
      <ul class="topcoat-list">
        <li class="topcoat-list__item">
          Item
        </li>
        <li class="topcoat-list__item">
          Item
        </li>
        <li class="topcoat-list__item">
          Item
        </li>
      </ul>
    </div>

*/
.topcoat-list__container {
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  overflow: auto;
  -webkit-overflow-scrolling: touch;
  border-top: 1px solid #2f3234;
  border-bottom: 1px solid #eff1f1;
  background-color: #444849;
}
.topcoat-list__header {
  margin: 0;
  padding: 0.3rem 1.6rem;
  font-size: 0.9em;
  font-weight: 400;
  background-color: #3b3e40;
  color: #868888;
  text-shadow: 0 -1px 0 rgba(0,0,0,0.3);
  border-top: solid 1px rgba(255,255,255,0.1);
  border-bottom: solid 1px rgba(255,255,255,0.05);
}
.topcoat-list {
  padding: 0;
  margin: 0;
  list-style-type: none;
  border-top: 1px solid #2f3234;
  color: #c6c8c8;
}
.topcoat-list__item {
  margin: 0;
  padding: 0;
  padding: 1.16rem;
  border-top: 1px solid #5e6061;
  border-bottom: 1px solid #2f3234;
}
.topcoat-list__item:first-child {
  border-top: 1px solid rgba(0,0,0,0.05);
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
.navigation-bar {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  white-space: nowrap;
  overflow: hidden;
  word-spacing: 0;
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.navigation-bar__item {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  position: relative;
  display: inline-block;
  vertical-align: top;
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
}
.navigation-bar__title {
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  -o-text-overflow: ellipsis;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
/*
Navigation Bar
--------------

    <div class="topcoat-navigation-bar">
        <div class="topcoat-navigation-bar__item center full">
            <h1 class="topcoat-navigation-bar__title">Header</h1>
        </div>
    </div>
*/
.topcoat-navigation-bar {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  white-space: nowrap;
  overflow: hidden;
  word-spacing: 0;
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  height: 2.6rem;
  padding-left: 1rem;
  padding-right: 1rem;
  background: #595b5b;
  color: #fff;
  -webkit-box-shadow: inset 0 -1px #333434, 0 1px rgba(0,0,0,0.15);
  box-shadow: inset 0 -1px #333434, 0 1px rgba(0,0,0,0.15);
}
.topcoat-navigation-bar__item {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  position: relative;
  display: inline-block;
  vertical-align: top;
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  margin: 0;
  line-height: 2.6rem;
  vertical-align: top;
}
.topcoat-navigation-bar__title {
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  -o-text-overflow: ellipsis;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
  font-size: 1.167rem;
  font-weight: 400;
  color: #fff;
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
input[type="radio"] {
  position: absolute;
  overflow: hidden;
  padding: 0;
  border: 0;
  opacity: 0.001;
  z-index: 1;
  vertical-align: top;
  outline: none;
}
.radio-button {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  position: relative;
  display: inline-block;
  vertical-align: top;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.radio-button__label {
  position: relative;
  display: inline-block;
  vertical-align: top;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.radio-button:before,
.radio-button:after {
  content: '';
  position: absolute;
  -webkit-border-radius: 100%;
  border-radius: 100%;
}
.radio-button:after {
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -moz-transform: translate(-50%, -50%);
  -o-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
}
.radio-button:before {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
}
.radio-button--disabled {
  opacity: 0.3;
  cursor: default;
  pointer-events: none;
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
input[type="radio"] {
  position: absolute;
  overflow: hidden;
  padding: 0;
  border: 0;
  opacity: 0.001;
  z-index: 1;
  vertical-align: top;
  outline: none;
}
.radio-button,
.topcoat-radio-button {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  position: relative;
  display: inline-block;
  vertical-align: top;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.radio-button__label,
.topcoat-radio-button__label {
  position: relative;
  display: inline-block;
  vertical-align: top;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.radio-button:before,
.radio-button:after,
.topcoat-radio-button:before,
.topcoat-radio-button:after {
  content: '';
  position: absolute;
  -webkit-border-radius: 100%;
  border-radius: 100%;
}
.radio-button:after,
.topcoat-radio-button:after {
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -moz-transform: translate(-50%, -50%);
  -o-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
}
.radio-button:before,
.topcoat-radio-button:before {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
}
.radio-button--disabled,
.topcoat-radio-button__label:disabled,
.topcoat-radio-button__label.is-disabled {
  opacity: 0.3;
  cursor: default;
  pointer-events: none;
}
/*
 Radio Button
 -----------

 :disabled - Disabled state

 .is-disabled - Simulates a disabled state on mobile devices

    <!-- NO LABEL -->
    <label class="topcoat-radio-button__label">
        <input type="radio" name="topcoat">
        <div class="topcoat-radio-button"></div>
    </label>
    <br>
    <!-- LEFT LABEL -->
    <label class="topcoat-radio-button__label">
        Left label
        <input type="radio" name="topcoat">
        <div class="topcoat-radio-button"></div>
    </label>
    <br>
    <!-- RIGHT LABEL -->
    <label class="topcoat-radio-button__label">
        <input type="radio" name="topcoat">
        <div class="topcoat-radio-button"></div>
        Right label
    </label>
*/
input[type="radio"] {
  height: 1rem;
  width: 1rem;
  margin-top: 0;
  margin-right: -1rem;
  margin-bottom: -1rem;
  margin-left: 0;
}
input[type="radio"]:checked + .topcoat-radio-button:after {
  opacity: 1;
}
.topcoat-radio-button__label {
  color: #c6c8c8;
  line-height: 1rem;
}
.topcoat-radio-button:before {
  width: 1rem;
  height: 1rem;
  background: #595b5b;
  border: 1px solid rgba(0,0,0,0.36);
  -webkit-box-shadow: inset 0 1px rgba(255,255,255,0.12);
  box-shadow: inset 0 1px rgba(255,255,255,0.12);
}
.topcoat-radio-button {
  position: relative;
  width: 1rem;
  height: 1rem;
}
.topcoat-radio-button:after {
  opacity: 0;
  width: 0.5rem;
  height: 0.5rem;
  background: #fff;
  border: 1px solid rgba(255,255,255,0.1);
  -webkit-box-shadow: 0 1px rgba(255,255,255,0.5);
  box-shadow: 0 1px rgba(255,255,255,0.5);
}
input[type="radio"]:focus + .topcoat-radio-button:before,
.topcoat-radio-button__label.is-focused > .topcoat-radio-button:before {
  border: 1px solid #0940fd;
  -webkit-box-shadow: 0 0 0 2px #6fb5f1;
  box-shadow: 0 0 0 2px #6fb5f1;
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
/*
 Search Input
 ------------

 :disabled - Disabled state

 .is-disabled - Simulates a disabled state

    <input type="search" value="" placeholder="search" class="topcoat-search-input">
    <input type="search is-disabled" value="" placeholder="search" class="topcoat-search-input">

 */
.topcoat-search-input,
.topcoat-search-input--large {
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  vertical-align: top;
  outline: none;
  height: 2rem;
  border: 1px solid rgba(0,0,0,0.36);
  background-color: #595b5b;
  -webkit-box-shadow: inset 0 1px rgba(0,0,0,0.18);
  box-shadow: inset 0 1px rgba(0,0,0,0.18);
  color: #c6c8c8;
  -webkit-appearance: none;
  padding: 0 0 0 2.7em;
  -webkit-border-radius: 15px;
  border-radius: 15px;
  background-image: url("../img/search_light.svg");
  background-position: 1em center;
  background-repeat: no-repeat;
  -webkit-background-size: 12px;
  -moz-background-size: 12px;
  background-size: 12px;
}
.topcoat-search-input:focus,
.topcoat-search-input--large:focus {
  background-color: #fff;
  color: #000;
}
.topcoat-search-input::-webkit-search-cancel-button,
.topcoat-search-input::-webkit-search-decoration {
  margin-right: 5px;
}
.topcoat-search-input:focus::-webkit-input-placeholder,
.topcoat-search-input:focus::-webkit-input-placeholder {
  color: #c6c8c8;
}
.topcoat-search-input:disabled,
.topcoat-search-input.is-disabled {
  opacity: 0.3;
  cursor: default;
  pointer-events: none;
}
/*
 Large Search Input
 ------------------

 :disabled - Disabled state

 .is-disabled - Simulates a disabled state

    <input type="search"  value="" placeholder="search" class="topcoat-search-input--large">
    <input type="search"  value="" placeholder="search" class="topcoat-search-input--large .is-disabled">

*/
.topcoat-search-input--large {
  height: 2.6rem;
  font-size: 1.167rem;
  font-weight: 200;
  padding-left: 2.8em;
  -webkit-border-radius: 25px;
  border-radius: 25px;
  background-position: 1.2em center;
  -webkit-background-size: 1.167rem;
  -moz-background-size: 1.167rem;
  background-size: 1.167rem;
}
.topcoat-search-input--large:disabled,
.topcoat-search-input--large.is-disabled {
  opacity: 0.3;
  cursor: default;
  pointer-events: none;
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
/*
 Text Input
 ----------

:disabled - Disabled state
.is-disabled - Simulates a disabled state on mobile devices

    <input type="text" class="topcoat-text-input" value="" placeholder="text">
    <input type="text" class="topcoat-text-input is-disabled" value="" placeholder="text">

*/
.topcoat-text-input,
.topcoat-text-input--large {
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  vertical-align: top;
  outline: none;
  height: 2rem;
  padding: 0 1.16rem;
  border: 1px solid rgba(0,0,0,0.36);
  -webkit-border-radius: 3px;
  border-radius: 3px;
  background-color: #595b5b;
  -webkit-box-shadow: inset 0 1px rgba(0,0,0,0.18);
  box-shadow: inset 0 1px rgba(0,0,0,0.18);
  color: #c6c8c8;
}
.topcoat-text-input:focus {
  background-color: #fff;
  color: #000;
}
.topcoat-text-input:disabled,
.topcoat-text-input.is-disabled {
  opacity: 0.3;
  cursor: default;
  pointer-events: none;
}
/*
 Large Text Input
 ----------------

:disabled - Disabled state
.is-disabled - Simulates a disabled state on mobile devices

    <input type="text" class="topcoat-text-input--large" value="" placeholder="text">
    <input type="text" class="topcoat-text-input--large is-disabled" value="" placeholder="text">
*/
.topcoat-text-input--large {
  height: 2.6rem;
  font-size: 1.167rem;
}
.topcoat-text-input--large:focus {
  background-color: #fff;
  color: #000;
}
.topcoat-text-input--large.is-disabled,
.topcoat-text-input--large:disabled {
  opacity: 0.3;
  cursor: default;
  pointer-events: none;
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
.textarea {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  vertical-align: top;
  resize: none;
  outline: none;
}

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/

/**
*
* Copyright 2012 Adobe Systems Inc.;
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
/*
Textarea
------------------------

    <textarea class="topcoat-textarea" rows="6" cols="36" placeholder="Textarea"></textarea>

 */
.topcoat-textarea,
.topcoat-textarea--large {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  vertical-align: top;
  resize: none;
  outline: none;
  padding: var-padding--container;
  font-size: var-font-size--textarea;
  font-weight: 200;
  -webkit-border-radius: 3px;
  border-radius: 3px;
  line-height: 2rem;
  border: 1px solid rgba(0,0,0,0.36);
  background-color: #595b5b;
  -webkit-box-shadow: inset 0 1px rgba(0,0,0,0.18);
  box-shadow: inset 0 1px rgba(0,0,0,0.18);
  color: #c6c8c8;
}
.topcoat-textarea:focus,
.topcoat-textarea--large:focus {
  background-color: #fff;
  color: #000;
}
/*
Large Textarea
------------------------

    <textarea class="topcoat-textarea--large" rows="6" cols="36" placeholder="Textarea"></textarea>

*/
.topcoat-textarea--large {
  font-size: var-font-size--textarea--large;
  line-height: 2.6rem;
}

@font-face {
  font-family: "Source Sans";
  src: url("../font/SourceSansPro-Regular.otf");
}
@font-face {
  font-family: "Source Sans";
  src: url("../font/SourceSansPro-Light.otf");
  font-weight: 200;
}
@font-face {
  font-family: "Source Sans";
  src: url("../font/SourceSansPro-Semibold.otf");
  font-weight: 600;
}

body {
  margin: 0;
  padding: 0;
  background: #3a3f42;
  color: #000;
  font: 16px "Source Sans", helvetica, arial, sans-serif;
  font-weight: 200;
  text-rendering: optimizeLegibility;
}
:focus {
  outline-color: transparent;
  outline-style: none;
}

.topcoat-icon--menu-stack {
  background: url("../img/hamburger_light.svg") no-repeat;
  -webkit-background-size: cover;
  -moz-background-size: cover;
  background-size: cover;
}

.quarter {
  width: 25%;
}
.half {
  width: 50%;
}
.three-quarters {
  width: 75%;
}
.third {
  width: 33.333%;
}
.two-thirds {
  width: 66.666%;
}
.full {
  width: 100%;
}

.left {
  text-align: left;
}
.center {
  text-align: center;
}
.right {
  text-align: right;
}

.reset-ui {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: padding;
  -moz-background-clip: padding;
  background-clip: padding-box;
  position: relative;
  display: inline-block;
  vertical-align: top;
  padding: 0;
  margin: 0;
  font: inherit;
  color: inherit;
  background: transparent;
  border: none;
  cursor: default;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -o-text-overflow: ellipsis;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
}





/* Call To Action */
/* Icons */
/* Navigation Bar */
/* Text Input */
/* Search Input */
/* List */
/* Checkbox */
/* Overlay */
/* Progress bar */
/* Checkbox */
/* Radio Button */

/* Icon Button */
/* Navigation bar */
/* List */
/* Search Input */
/* Topcoat icon large */
/* otherwise the icon is off-center */
/* Checkbox */
/* Radio */

/* Call To Action */
/* Icons */
/* Navigation Bar */
/* Text Input */
/* List */
/* Overlay */
/* Progress bar */
/* Checkbox */
/* Radio Button */
/* Range input */

/* Containers */
/* Icon Button */
/* Navigation bar */
/* List */
/* Search Input */
/* Text Area */
/* Checkbox */
/* Radio */
/* Range input */

/* Text Input */
/* Radio input */
/* Overlay */
/* Textarea */
/* Progress bar container */
/* Progress bar progress */

