// Generated by CoffeeScript 1.6.3
var $, Fullscreen, exports;

$ = jQuery;

Fullscreen = (function() {
  var _fullscreen_hint_sel;

  _fullscreen_hint_sel = '#js-fullscreen-hint';

  function Fullscreen() {
    if (screenfull.enabled) {
      $(_fullscreen_hint_sel).show(function() {
        return $(document).bind('keypress', function(e) {
          var code;
          code = (e.keyCode ? e.keyCode : e.which);
          if (!$('input').is(':focus') && (code === 70 || code === 102)) {
            return screenfull.toggle();
          }
        });
      });
    }
  }

  return Fullscreen;

})();

exports = this;

exports.Fullscreen = Fullscreen;
